import * as tslib_1 from "tslib";
import { forwardRef, Input } from '@angular/core';
import { IgxCategoryAngleAxisComponent } from "./igx-category-angle-axis-component";
import { IgxNumericRadiusAxisComponent } from "./igx-numeric-radius-axis-component";
import { IgxMarkerSeriesComponent } from "./igx-marker-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { ensureBool, toPoint } from "igniteui-angular-core/ES2015/componentUtil";
/**
 * Represents the base class for all IgxDataChartComponent radial series
*/
export const IgxRadialBaseComponent_PROVIDERS = [{ provide: IgxMarkerSeriesComponent, useExisting: forwardRef(() => IgxRadialBaseComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxRadialBaseComponent) }];
export class IgxRadialBaseComponent extends IgxMarkerSeriesComponent {
    constructor() {
        super();
    }
    get i() {
        return this._implementation;
    }
    /**
     * Checks if this series is a radial series
    */
    get isRadial() {
        return this.i.c2;
    }
    /**
     * Gets the effective angle axis for the current series object.
    */
    get angleAxis() {
        if (this.i.ms == null) {
            return null;
        }
        if (!this.i.ms.externalObject) {
            let e = new IgxCategoryAngleAxisComponent();
            e._implementation = this.i.ms;
            this.i.ms.externalObject = e;
        }
        return this.i.ms.externalObject;
    }
    set angleAxis(v) {
        v == null ? this.i.ms = null : this.i.ms = v.i;
    }
    /**
     * Gets the effective value axis for the current series object.
    */
    get valueAxis() {
        if (this.i.mu == null) {
            return null;
        }
        if (!this.i.mu.externalObject) {
            let e = new IgxNumericRadiusAxisComponent();
            e._implementation = this.i.mu;
            this.i.mu.externalObject = e;
        }
        return this.i.mu.externalObject;
    }
    set valueAxis(v) {
        v == null ? this.i.mu = null : this.i.mu = v.i;
    }
    /**
     * Gets or sets whether to clip the series to the bounds.
     * Setting this property to true will decrease chart performance.
    */
    get clipSeriesToBounds() {
        return this.i.m3;
    }
    set clipSeriesToBounds(v) {
        this.i.m3 = ensureBool(v);
    }
    /**
     * Determine if object can be used as ValueAxis
    
    * @param axis  * The object to check
    */
    canUseAsValueAxis(axis) {
        let iv = this.i.m2(axis);
        return (iv);
    }
    /**
     * Determine if object can be used as AngleAxis
    
    * @param axis  * The object to check
    */
    canUseAsAngleAxis(axis) {
        let iv = this.i.m1(axis);
        return (iv);
    }
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    getItem(world) {
        let iv = this.i.fm(toPoint(world));
        return (iv);
    }
    /**
     * Gets the angle to the provided world position from the center of the radial series.
    
    * @param world  * The world position to get the angle for
    */
    getAngleFromWorld(world) {
        let iv = this.i.m5(toPoint(world));
        return (iv);
    }
    /**
     * Gets the precise item index, if possible, based on the closeness to the previous or next whole integer. If the series cannot provide this information, GetExactItemIndex will return the same integer value as GetItemIndex.
    
    * @param world  * The world position for which to return the index.
    */
    getExactItemIndex(world) {
        let iv = this.i.m6(toPoint(world));
        return (iv);
    }
    /**
     * Get the index of the item near the provided world coordinates.
    
    * @param world  * The world coordinates for which to getch the item index.
    */
    getItemIndex(world) {
        let iv = this.i.e5(toPoint(world));
        return (iv);
    }
    /**
     * Scrolls the specified item into the view.
    
    * @param item  * The item to scroll into view.
    */
    scrollIntoView(item) {
        let iv = this.i.c8(item);
        return (iv);
    }
    /**
     * Returns the offset value for this series if grouped on a category axis.
    
    */
    getOffsetValue() {
        let iv = this.i.getOffsetValue();
        return (iv);
    }
    /**
     * Returns the width of the category grouping this series is in.
    
    */
    getCategoryWidth() {
        let iv = this.i.getCategoryWidth();
        return (iv);
    }
}
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", IgxCategoryAngleAxisComponent),
    tslib_1.__metadata("design:paramtypes", [IgxCategoryAngleAxisComponent])
], IgxRadialBaseComponent.prototype, "angleAxis", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", IgxNumericRadiusAxisComponent),
    tslib_1.__metadata("design:paramtypes", [IgxNumericRadiusAxisComponent])
], IgxRadialBaseComponent.prototype, "valueAxis", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Boolean),
    tslib_1.__metadata("design:paramtypes", [Boolean])
], IgxRadialBaseComponent.prototype, "clipSeriesToBounds", null);
//# sourceMappingURL=igx-radial-base-component.js.map