import * as tslib_1 from "tslib";
import { forwardRef, Input } from '@angular/core';
import { IgxNumericXAxisComponent } from "./igx-numeric-x-axis-component";
import { IgxNumericYAxisComponent } from "./igx-numeric-y-axis-component";
import { IgxSeriesComponent } from "./igx-series-component";
/**
 * Series class for rendering polygons.
*/
export const IgxShapeSeriesBaseComponent_PROVIDERS = [{ provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxShapeSeriesBaseComponent) }];
export class IgxShapeSeriesBaseComponent extends IgxSeriesComponent {
    constructor() {
        super();
    }
    get i() {
        return this._implementation;
    }
    /**
     * The name of the property on ItemsSource items which, for each shape, contains a list of points to be converted to a polygon.
     * To be consistent with the Shapefile technical description, it is expected that each list of points is defined as an IEnumerable of IEnumerable of Point, or in other words, a list of lists of points.
    */
    get shapeMemberPath() {
        return this.i.mk;
    }
    set shapeMemberPath(v) {
        this.i.mk = v;
    }
    /**
     * Gets or sets the effective x-axis for the current ScatterBase object.
    */
    get xAxis() {
        if (this.i.ly == null) {
            return null;
        }
        if (!this.i.ly.externalObject) {
            let e = new IgxNumericXAxisComponent();
            e._implementation = this.i.ly;
            this.i.ly.externalObject = e;
        }
        return this.i.ly.externalObject;
    }
    set xAxis(v) {
        v == null ? this.i.ly = null : this.i.ly = v.i;
    }
    /**
     * Gets or sets the effective y-axis for the current ScatterBase object.
    */
    get yAxis() {
        if (this.i.l0 == null) {
            return null;
        }
        if (!this.i.l0.externalObject) {
            let e = new IgxNumericYAxisComponent();
            e._implementation = this.i.l0;
            this.i.l0.externalObject = e;
        }
        return this.i.l0.externalObject;
    }
    set yAxis(v) {
        v == null ? this.i.l0 = null : this.i.l0 = v.i;
    }
    /**
     * The resolution at which to filter out shapes in the series.  For example, if the ShapeFilterResolution is set to 3, then elements with a bounding rectangle smaller than 3 X 3 pixels will be filtered out.
     * In the case of ScatterPolylineSeries, the resolution is compared to either dimension, rather than both.  In other words, a polyline will not be filtered if its height or its width exceeds the value of this property.  Whereas with a ShapeSeries, both the height and the width must exceed the value of this property.
    */
    get shapeFilterResolution() {
        return this.i.mf;
    }
    set shapeFilterResolution(v) {
        this.i.mf = +v;
    }
    /**
     * Gets whether or not this series is a shape series
    */
    get isShape() {
        return this.i.c5;
    }
    /**
     * Determine if object can be used as YAxis
    
    * @param axis  * The object to check
    */
    canUseAsYAxis(axis) {
        let iv = this.i.l5(axis);
        return (iv);
    }
    /**
     * Determine if object can be used as XAxis
    
    * @param axis  * The object to check
    */
    canUseAsXAxis(axis) {
        let iv = this.i.l4(axis);
        return (iv);
    }
}
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", String),
    tslib_1.__metadata("design:paramtypes", [String])
], IgxShapeSeriesBaseComponent.prototype, "shapeMemberPath", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", IgxNumericXAxisComponent),
    tslib_1.__metadata("design:paramtypes", [IgxNumericXAxisComponent])
], IgxShapeSeriesBaseComponent.prototype, "xAxis", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", IgxNumericYAxisComponent),
    tslib_1.__metadata("design:paramtypes", [IgxNumericYAxisComponent])
], IgxShapeSeriesBaseComponent.prototype, "yAxis", null);
tslib_1.__decorate([
    Input(),
    tslib_1.__metadata("design:type", Number),
    tslib_1.__metadata("design:paramtypes", [Number])
], IgxShapeSeriesBaseComponent.prototype, "shapeFilterResolution", null);
//# sourceMappingURL=igx-shape-series-base-component.js.map