import * as tslib_1 from "tslib";
import { EventEmitter, Output, Component, Input, ChangeDetectionStrategy } from '@angular/core';
import { delegateCombine } from "igniteui-angular-core/ES5/type";
import { PropertyUpdatedEventArgs } from "igniteui-angular-core/ES5/igx-property-updated-event-args";
import { BrushScale } from "./BrushScale";
import { toBrushCollection, fromBrushCollection, brushToString } from "igniteui-angular-core/ES5/componentUtil";
/**
 * Represents a base class for brush scales.
*/
export var IgxBrushScaleComponent_PROVIDERS = [];
var IgxBrushScaleComponent = /** @class */ (function () {
    function IgxBrushScaleComponent() {
        this._propertyUpdated = null;
        this._zoneRunner = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgxBrushScaleComponent.prototype.createImplementation = function () {
        return new BrushScale();
    };
    IgxBrushScaleComponent.prototype.ngOnInit = function () {
    };
    Object.defineProperty(IgxBrushScaleComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    IgxBrushScaleComponent.prototype.onImplementationCreated = function () {
    };
    Object.defineProperty(IgxBrushScaleComponent.prototype, "brushes", {
        /**
         * Gets the brushes collection used by this scale.
        */
        get: function () {
            return fromBrushCollection(this.i.brushes);
        },
        set: function (v) {
            this.i.brushes = toBrushCollection(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxBrushScaleComponent.prototype, "isReady", {
        /**
         * Gets the status of the scale
        */
        get: function () {
            return this.i.isReady;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxBrushScaleComponent.prototype, "isBrushScale", {
        /**
         * Checks if this item is a BrushScale
        */
        get: function () {
            return this.i.isBrushScale;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Registers a series with the scale. Under normal circumstances you should not need to call this manually.
    
    * @param series  * The series to register with the scale.
    */
    IgxBrushScaleComponent.prototype.registerSeries = function (series) {
        this.i.registerSeries((series == null ? null : series.i));
    };
    /**
     * Unregisters a series with the scale. Under normal circumstances you should not need to call this manually.
    
    * @param series  * The series to unregister from the scale.
    */
    IgxBrushScaleComponent.prototype.unregisterSeries = function (series) {
        this.i.unregisterSeries((series == null ? null : series.i));
    };
    /**
     * Gets a brush from the brushes collection by index.
    
    */
    IgxBrushScaleComponent.prototype.getBrush = function (index) {
        var iv = this.i.getBrush(index);
        return brushToString(iv);
    };
    Object.defineProperty(IgxBrushScaleComponent.prototype, "propertyUpdated", {
        /**
         * Event raised when a property (including "effective" and non-dependency property) value changes.
        */
        get: function () {
            var _this = this;
            if (this._propertyUpdated == null) {
                this._propertyUpdated = new EventEmitter();
                this.i.propertyUpdated = delegateCombine(this.i.propertyUpdated, function (o, e) {
                    _this._runInZone(function () {
                        var outerArgs = new PropertyUpdatedEventArgs();
                        outerArgs._provideImplementation(e);
                        if (_this.beforePropertyUpdated) {
                            _this.beforePropertyUpdated(_this, outerArgs);
                        }
                        _this._propertyUpdated.emit({
                            sender: _this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._propertyUpdated;
        },
        enumerable: true,
        configurable: true
    });
    IgxBrushScaleComponent.prototype._runInZone = function (act) {
        if (this._zoneRunner != null) {
            this._zoneRunner(act);
        }
        else {
            act();
        }
    };
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Array),
        tslib_1.__metadata("design:paramtypes", [Array])
    ], IgxBrushScaleComponent.prototype, "brushes", null);
    tslib_1.__decorate([
        Output(),
        tslib_1.__metadata("design:type", EventEmitter),
        tslib_1.__metadata("design:paramtypes", [])
    ], IgxBrushScaleComponent.prototype, "propertyUpdated", null);
    IgxBrushScaleComponent = tslib_1.__decorate([
        Component({
            selector: 'igx-brush-scale',
            template: "",
            providers: [],
            changeDetection: ChangeDetectionStrategy.OnPush
        }),
        tslib_1.__metadata("design:paramtypes", [])
    ], IgxBrushScaleComponent);
    return IgxBrushScaleComponent;
}());
export { IgxBrushScaleComponent };
//# sourceMappingURL=igx-brush-scale-component.js.map